using System;
using Microsoft.SPOT;

namespace Robot_F6
{
    public interface IDualMotorDriver
    {
        /// <summary>
        /// Set M1 and M2 to move left forwards
        /// </summary>
        void MoveForwards();
        
        /// <summary>
        /// Set M1 and M2 to move right backwards
        /// </summary>
        void MoveBackwards();

        /// <summary>
        /// Set M1 and M2 to turn clockwise: M1 backwards, M2 forwards
        /// </summary>
        void TurnClockwise();
        
        /// <summary>
        /// Set M1 and M2 to turn counter clockwise: M1 forwards, M2 backwards
        /// </summary>
        void TurnCounterClockwise();
        
        /// <summary>
        /// Set M1 and M2 to move left forwards: M1 moves slower than M2
        /// </summary>
        void MoveLeftForwards();

        /// <summary>
        /// Set M1 and M2 to move left forwards: M1 moves faster than M2
        /// </summary>
        void MoveRightForwards();

        /// <summary>
        /// Set M1 and M2 to move left backwards: M1 moves slower than M2
        /// </summary>
        void MoveLeftBackwards();

        /// <summary>
        /// Set M1 and M2 to move left backwards: M1 moves faster than M2
        /// </summary>
        void MoveRightBackwards();

        /// <summary>
        /// Set M1 and M2 to stop
        /// </summary>
        void Stop();

        /// <summary>
        /// Set M1 and M2 to break
        /// </summary>
        void Break();

        /// <summary>
        /// Move M1 and M2 one step
        /// </summary>
        void Step();

        /// <summary>
        /// Change to 'fast motion'
        /// </summary>
        void Fast();

        /// <summary>
        /// Change to 'slow motion'
        /// </summary>
        void Slow();

        void NormalSpeed();
    }
}
