using System;
using Microsoft.SPOT;
using Gadgeteer.Modules.GHIElectronics;
using GT = Gadgeteer;
using GTM = Gadgeteer.Modules;
using Gadgeteer.Interfaces;
namespace Robot_F6
{
    public enum MotorState { Break = -1, Stop, MoveForwards, MoveBackwards}

    public interface IMotor
    {
        
        /// <summary>
        /// Signal will be every Nth step enabled
        /// If n = 5 then signal will be enabled on 5th, 10th, 15th,....: ddddEddddEddddEddddE
        /// </summary>
        uint NthStepActive { get; set;}

        /// <summary>
        /// When stepping is used, step moves to the next step. Motor is enabled every nth step
        /// </summary>
        void Step();
        
        /// <summary>
        /// Stop the motor
        /// </summary>
        void Stop();

        /// <summary>
        /// Break == Stop, but you can have different behaviour: e.g. break enables some led lights
        /// </summary>
        void Break();

        /// <summary>
        /// Set the motor state: stop, move forwards, move backwards or break
        /// </summary>
        /// <param name="motorState"></param>
        void SetMotorState(MotorState motorState);
        
        /// <summary>
        /// Sets or gets the value used for activating the motor. For normal use active should be true, for negative logic, use false
        /// </summary>
        bool ActiveValue { get; set; }
        
    }
}
