using System;
using Microsoft.SPOT;
using Gadgeteer.Modules.GHIElectronics;
using GT = Gadgeteer;
using GTM = Gadgeteer.Modules;
using Gadgeteer.Interfaces;
namespace Robot_F6
{
    public class Motor : IMotor
    {
        private bool _activeValue = true;

        private GT.Interfaces.DigitalOutput _contact1;
        private GT.Interfaces.DigitalOutput _contact2;
        private MotorState currentMotorState = MotorState.Stop;

        private uint stepCounter = 0;
        private uint nThStepActive = 1; // every step

        public Motor(GT.Interfaces.DigitalOutput contact1, GT.Interfaces.DigitalOutput contact2)
        {
            _contact1 = contact1;
            _contact2 = contact2;
        }
        
        public bool ActiveValue
        {
            get { return _activeValue; }
            set { _activeValue = value; }
        }

        public uint NthStepActive
        {
            get 
            {
                return nThStepActive; 
            }
            set 
            {
                if (nThStepActive > 0 && nThStepActive <= 100)
                {
                    nThStepActive = value;
                    stepCounter = 0;
                }

            }
        }
        
        public void Stop()
        {
            SetMotorState(MotorState.Stop);
        }

        public void Break()
        {
            SetMotorState(MotorState.Break);
        }

        public void SetMotorState(MotorState motorState)
        {
            currentMotorState = motorState;
            Step();
        }

        public void Step()
        {
            stepCounter++;
            if (stepCounter == nThStepActive)
            {
                stepCounter = 0;
                switch (currentMotorState)
                {
                    case MotorState.MoveForwards:
                        {
                            _contact1.Write(_activeValue);
                            _contact2.Write(!_activeValue);
                            break;
                        }
                    case MotorState.MoveBackwards:
                        {
                            _contact1.Write(!_activeValue);
                            _contact2.Write(_activeValue);
                            break;
                        }
                    case MotorState.Stop:
                        {
                            _contact1.Write(!_activeValue);
                            _contact2.Write(!_activeValue);
                            break;
                        }
                    case MotorState.Break:
                        {
                            _contact1.Write(_activeValue);
                            _contact2.Write(_activeValue);
                            break;
                        }
                    default:
                        throw new ArgumentOutOfRangeException("Unknown motor state:" + currentMotorState);
                }
            }
            else
            {
                _contact1.Write(!_activeValue);
                _contact2.Write(!_activeValue);
            }

        }
    }
}
