using System;
using System.Collections;
using System.Threading;
using Microsoft.SPOT;
using Microsoft.SPOT.Presentation;
using Microsoft.SPOT.Presentation.Controls;
using Microsoft.SPOT.Presentation.Media;
using Microsoft.SPOT.Touch;

using Gadgeteer.Networking;
using GT = Gadgeteer;
using GTM = Gadgeteer.Modules;
using Gadgeteer.Interfaces;
using Gadgeteer.Modules.GHIElectronics;
using Gadgeteer;
using Gadgeteer.Modules.Seeed;

namespace Robot_F6
{
    public class WebRequestHandler : IWebRequestHandler
    {
        public ICommand NorthCommand { get; set; }
        public ICommand NorthEastCommand { get; set; }
        public ICommand EastCommand { get; set; }
        public ICommand SouthEastCommand { get; set; }
        public ICommand SouthCommand { get; set; }
        public ICommand SouthWestCommand { get; set; }
        public ICommand WestCommand { get; set; }
        public ICommand NorthWestCommand { get; set; }
        public ICommand StopCommand { get; set; }
        public ICommand StartCommand { get; set; }
        public ICommand FireCommand { get; set; }
        public ICommand FastCommand { get; set; }
        public ICommand SlowCommand { get; set; }
        public ICommand BreakCommand { get; set; }


        public ITemperatureMeasurer TemperatureMeasurer { get; set; }
        public IHumidityMeasurer HumidityMeasurer { get; set; }

        public WebRequestHandler()
        {
        }

        public void HandleRequest(GTM.GHIElectronics.HttpStream request)
        {
            string requestedURL = request.Request.URL;
            if (requestedURL.IndexOf("/_") == 0)
            {
                HandleAjaxHttpRequest(request, requestedURL);
            }
            else
            {
                HandleHttpRequest(request, requestedURL);
            }
        }

        private void HandleHttpRequest(GTM.GHIElectronics.HttpStream request, string requestedURL)
        {
            string response = "Unkown action";
            if (requestedURL == "/index.html" || requestedURL == "/") { response = "Welcome"; }
            else { response = "Unknown action"; }
            //response = "<!DOCTYPE html>\n<html lang=\"en\" xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n <meta charset=\"utf-8\" />\n <title></title>\n</head>\n \n<body>\n <style>\n td {\n width:160px;\n vertical-align:central\n }\n input[type=\"button\"] {\n font-size:144px;\n background-color:beige;\n text-align:center;\n color:black;\n font-weight:bold;\n width:150px;\n height:150px;\n vertical-align:central\n\n }\n\n input[type=\"button\"].x {\n font-size:12px;\n }\n\n #btnStop {\n background-color:red;\n font-size:32px;\n }\n\n #btnStart {\n background-color:green;\n font-size:32px;\n }\n #lbInfo {\n display: block;\n float: right;\n width:300px;\n background-color:white;\n font-size:24px;\n text-align:center\n }\n\n </style>\n <script type=\"text/javascript\">\n var xmlhttp;\n if (window.XMLHttpRequest) {\n xmlhttp = new XMLHttpRequest();\n }\n else {\n xmlhttp = new ActiveXObject(\"Microsoft.XMLHTTP\");\n }\n\n\n function move(direction) {\n \n xmlhttp.onreadystatechange = function () {\n if (xmlhttp.readyState == 4 && xmlhttp.status == 200) {\n  document.getElementById(\"lbInfo\").innerHTML = xmlhttp.responseText;\n }\n }\n xmlhttp.open(\"GET\", \"http://192.168.1.1/_\" + direction + \".html\", true);\n xmlhttp.send();\n };\n\n function northwest() { \n move('northwest');\n };\n function north() {\n \n move('north');\n };\n function northeast() {\n \n move('northeast');\n };\n function west() {\n move('west');\n };\n function doFire() {\n move('fire');\n };\n function east() {\n move('east');\n };\n function southwest() {\n move('southwest');\n };\n function south() {\n move('south');\n };\n function southeast() {\n move('southeast');\n };\n function doStart() {\n move('start');\n };\n function doStop() {\n move('stop');\n };\n\n </script>\n <table>\n <tr>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnNorthWest\" onclick=\"northwest()\"/></td>\n <td><input type=\"button\" value=\"/\\\" id=\"btnUp\" onclick=\"north()\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnNorthEast\" onclick=\"northeast()\"/></td>\n <td></td>\n <td><input type=\"button\" value=\"STOP\" id=\"btnStop\" onclick=\"doStop()\"/></td>\n </tr>\n <tr>\n <td><input type=\"button\" value=\"<\" id=\"btnWest\" onclick=\"west()\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnCenter\" onclick=\"doFire()\"/></td>\n <td><input type=\"button\" value=\">\" id=\"btnEast\" onclick=\"east()\"/></td>\n <td colspan=\"2\"><label id=\"lbInfo\">" + response + "</label></td>\n </tr>\n <tr>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnSouthWest\" onclick=\"southwest()\"/></td>\n <td><input type=\"button\" value=\"\\/\" id=\"btnSouth\" onclick=\"south()\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnSouthEast\" onclick=\"southeast()\"/></td>\n <td></td>\n <td><input type=\"button\" value=\"START\" id=\"btnStart\" onclick=\"doStart()\"/></td>\n </tr>\n </table>\n</body>\n</html>";
            response = "<!DOCTYPE html>\n<html lang=\"en\" xmlns=\"http://www.w3.org/1999/xhtml\">\n<head>\n <meta charset=\"utf-8\" />\n <title>Robot F6</title>\n</head>\n<body>\n <style>\n td {\n width:160px;\n vertical-align:central\n }\n input[type=\"button\"] {\n font-size:144px;\n background-color:beige;\n text-align:center;\n color:black;\n font-weight:bold;\n width:150px;\n height:150px;\n vertical-align:central\n\n }\n\n input[type=\"button\"].x {\n font-size:12px;\n }\n\n #btnStop {\n background-color:red;\n font-size:32px;\n }\n\n #btnStart {\n background-color:green;\n font-size:32px;\n }\n \n #btnFast {\n background-color:midnightblue;\n color:white;\n font-size:32px;\n }\n \n #btnSlow {\n background-color:yellow;\n font-size:32px;\n }\n #lbInfo {\n display: block;\n float: right;\n width:300px;\n background-color:white;\n font-size:24px;\n text-align:center\n }\n\n </style>\n <script type=\"text/javascript\">\n var xmlhttp;\n if (window.XMLHttpRequest) {\n xmlhttp = new XMLHttpRequest();\n }\n else {\n xmlhttp = new ActiveXObject(\"Microsoft.XMLHTTP\");\n }\n\n function submitAction(action) {\n\n xmlhttp.onreadystatechange = function () {\n if (xmlhttp.readyState == 4 && xmlhttp.status == 200) {\n document.getElementById(\"lbInfo\").innerHTML = xmlhttp.responseText;\n }\n }\n xmlhttp.open(\"GET\", \"http://192.168.1.1/_\" + action, true);\n xmlhttp.send();\n }\n\n\n window.setInterval(submitAction('getdataX'), 1000); </script>\n <table>\n <tr>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnNorthWest\" onclick=\"submitAction('northwest');\"/></td>\n <td><input type=\"button\" value=\"/\\\" id=\"btnUp\" onclick=\"submitAction('north');\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnNorthEast\" onclick=\"submitAction('northeast');\"/></td>\n <td><input type=\"button\" value=\"START\" id=\"btnStart\" onclick=\"submitAction('start');\"/></td>\n <td><input type=\"button\" value=\"STOP\" id=\"btnStop\" onclick=\"submitAction('stop');\"/></td>\n </tr>\n <tr>\n <td><input type=\"button\" value=\"<\" id=\"btnWest\" onclick=\"submitAction('west');\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnCenter\" onclick=\"submitAction('fire');\"/></td>\n <td><input type=\"button\" value=\">\" id=\"btnEast\" onclick=\"submitAction('east');\"/></td>\n <td colspan=2><label id=\"lbInfo\">Welcome to Robot-F6. Please tell me what to do.</label></td>\n\n </tr>\n <tr>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnSouthWest\" onclick=\"submitAction('southwest');\"/></td>\n <td><input type=\"button\" value=\"\\/\" id=\"btnSouth\" onclick=\"submitAction('south');\"/></td>\n <td><input type=\"button\" class=\"x\" value=\"x\" id=\"btnSouthEast\" onclick=\"submitAction('southeast');\"/></td>\n <td><input type=\"button\" value=\"SLOW\" id=\"btnFast\" onclick=\"submitAction('slow');\"/></td>\n <td><input type=\"button\" value=\"FAST\" id=\"btnFast\" onclick=\"submitAction('fast');\"/></td>\n </tr>\n </table>\n</body>\n</html>";
            SendResponse(request, response);
        }

        private void HandleAjaxHttpRequest(GTM.GHIElectronics.HttpStream request, string requestedURL)
        {
            bool responseWasHandled = false;
            string response = "";
            switch (requestedURL)
            {
                case "/_index":
                    response = "Welcome";
                    break;
                case "/_northwest":
                    response += "north west";
                    if(NorthWestCommand != null){ NorthWestCommand.Execute();}
                    break;
                case "/_north":
                    response += "north";
                    if(NorthCommand != null){ NorthCommand.Execute();}
                    break;
                case "/_northeast":
                    response += "north east";
                    if(NorthEastCommand != null){ NorthEastCommand.Execute();}
                    break;
                case "/_west":
                    response += "west";
                    if(WestCommand != null){ WestCommand.Execute();}
                    break;
                case "/_east":
                    response += "east";
                    if (EastCommand != null) { EastCommand.Execute(); }
                    break;
                case "/_southwest":
                    if( SouthWestCommand!= null){ SouthWestCommand.Execute();}
                    break;
                case "/_south":
                    response = "We're going down south";
                    if(SouthCommand != null){ SouthCommand.Execute();}
                    break;
                case "/_southeast":
                    if(SouthEastCommand != null){ SouthEastCommand.Execute();}
                    break;
                case "/_start":
                    response = "Let's go";
                    if(StartCommand != null){ StartCommand.Execute();}
                    break;
                case "/_fast":
                    response = "Fast";
                    if (FastCommand != null) { FastCommand.Execute(); }
                    break;
                case "/_slow":
                    response = "Slow";
                    if (SlowCommand != null) { SlowCommand.Execute(); }
                    break;
                case "/_stop":
                    response = "Hold it, right there!";
                    if(StopCommand != null){ StopCommand.Execute();}
                    break;
                case "/_fire":
                    if(TemperatureMeasurer != null)
                    {
                        response = "Temp: " + TemperatureMeasurer.GetTemperature().ToString("f2") + "C ";
                    }

                    if(HumidityMeasurer != null)
                    {
                        response += " Humidity: " + HumidityMeasurer.GetHumidity().ToString("f2") + "%";
                    }
                    if (FireCommand != null) { FireCommand.Execute(); }
                    break;
                case "/_getdataX":
                    if(TemperatureMeasurer != null)
                    {
                        response = "Temp: " + TemperatureMeasurer.GetTemperature().ToString("f2") + "C ";
                    }

                    if(HumidityMeasurer != null)
                    {
                        response += " Humidity: " + HumidityMeasurer.GetHumidity().ToString("f2") + "%";
                    }
                    break;
                default:
                    response = "Unknown action";
                    break;
            }
            if (!responseWasHandled)
            {
                SendResponse(request, response);
            }
        }

        private void SendResponse(GTM.GHIElectronics.HttpStream request, string response)
        {
            byte[] document = System.Text.Encoding.UTF8.GetBytes(response);
            request.Response.HeaderData["Content-type"] = "text/html; charset=utf-8";
            request.Response.HeaderData["Connection"] = "close";
            request.Response.HeaderData["Cache-Control"] = "no-cache";
            request.Response.HeaderData["Content-Length"] = document.Length.ToString();
            request.Response.StatusCode = GTM.GHIElectronics.HttpResponse.ResponseStatus.OK;
            request.Response.Send(document);
        }
    }
}
